const {
  csv,
  select,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
} = d3;

const csvUrl =
  'https://raw.githubusercontent.com/SAITEJAUPPU/Activity8_Dataset/main/insurance.csv';

const parseRow = (d) => ({
  age: +d.age,
  sex: d.sex,
  bmi: +d.bmi,
  children: +d.children,
  smoker: d.smoker,
  region: d.region,
  charges: +d.charges,
});

const xValue = (d) => d.age;
const yValue = (d) => d.bmi;

const margin = { top: 30, right: 50, bottom: 50, left: 90 };
const radius = 5;
const width =
  window.innerWidth - margin.left - margin.right;
const height =
  window.innerHeight - 110 - margin.top - margin.bottom;

const svg = select('#scatter-plot')
  .attr('width', width + margin.left + margin.right)
  .attr('height', height + margin.top + margin.bottom)
  .append('g')
  .attr(
    'transform',
    `translate(${margin.left},${margin.top})`,
  );

const main = async () => {
  const data = await csv(csvUrl, parseRow);
  const x = scaleLinear()
    .domain(extent(data, xValue))
    .nice()
    .range([0, width]);
  const y = scaleLinear()
    .domain(extent(data, yValue))
    .nice()
    .range([height, 0]);

  // Assigning colors based on countries
  const colorScale = d3.scaleOrdinal(d3.schemeCategory10);

  const marks = data.map((d) => ({
    x: x(xValue(d)),
    y: y(yValue(d)),
    color: colorScale(d.region),
  }));

  svg
    .selectAll('.circle')
    .data(marks)
    .enter()
    .append('circle')
    .attr('class', 'circle')
    .attr('cx', (d) => d.x)
    .attr('cy', (d) => d.y)
    .attr('fill', (d) => d.color)
    .attr('r', radius);

  svg
    .append('g')
    .attr('class', 'axis')
    .attr('transform', `translate(0,${height})`)
    .call(axisBottom(x));

  svg
    .append('text')
    .attr('class', 'axis-label')
    .attr('x', width / 2)
    .attr('y', height + margin.bottom / 1.2)
    .text('Age');

  svg.append('g').attr('class', 'axis').call(axisLeft(y));

  svg
    .append('text')
    .attr('class', 'axis-label')
    .attr('transform', 'rotate(-90)')
    .attr('x', -height / 2)
    .attr('y', -margin.left / 1.5)
    .text('BMI');
};

main();
